/**
 * @file gui_demo_p2.c
 * @brief quick examples for GUI usage
 * @author Duboisset Philippe
 * @version 0.1b
 * @date (yyyy-mm-dd) 2013-07-13
 *
 * Copyright (C) <2013>  Duboisset Philippe <duboisset.philippe@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
#include "gui_demo.h"

#define SIG_BTN_PREV          1
#define SIG_BTN_NEXT          2
#define SIG_DISABLE_OBJ       3
#define SIG_NOTIFY_OBJ        4

#define SIG_CHECKBOX          5
#define SIG_RADIO_1_A         10
#define SIG_RADIO_1_B         11
#define SIG_RADIO_1_C         12
#define SIG_RADIO_2_A         20
#define SIG_RADIO_2_B         21
#define SIG_RADIO_2_C         22




void DemoPage2(void) {


  rect_st rec;
  uint8_t done = 0;

  g_obj_st *pNotifiedButton, *pDisabledButton, *pNotifiedCheck, *pDisabledCheck, *pNotifiedRadio, *pDisabledRadio;
  uint8_t disableObj = 0, notifyObj = 0, check = 0;

  uint8_t radio1 = 1, radio2 = 1;


  /*
   * Page construction
   */

  /*delete all objects & clear the screen*/
  GUI_ClearAll();

  /*title*/
  rec = GUI_Rect(5, 0, 310, 215);
  SetFont(G_FONT_BOLD);
  GUI_AddFrame(&rec, "Button, CheckBox & Radio");
  SetFont(G_FONT_DEFAULT);

  /**
   * add some various buttons (not connected to any signal)
   */
  rec = GUI_Rect(10, 25, 68, 21);
  GUI_AddButton(&rec, "no image", 0); /*0 <=> no image*/

  rec = GUI_Rect(80, 25, 20, 21);
  GUI_AddButton(&rec, NULL /*no text*/, 41); /*41 <=> image <idea>*/

  rec = GUI_Rect(10, 47, 90, 21);
  GUI_AddButton(&rec, "Image", 42); /*42 <=> image <smiley>*/

  rec = GUI_Rect(10, 69, 90, 21);
  SetColor(G_COL_TEXT, P2D_Color(255, 0, 0));
  GUI_AddButton(&rec, "color", 43); /*43 <=> image <music>*/
  SetColor(G_COL_TEXT, P2D_Color(0, 0, 0));

  rec = GUI_Rect(10, 91, 90, 21);
  SetFont(G_FONT_BOLD);
  GUI_AddButton(&rec, "font", 1); /*1 <=> image <OK>*/
  SetFont(G_FONT_DEFAULT);

  rec = GUI_Rect(10, 113, 90, 21);
  pNotifiedButton = GUI_AddButton(&rec, "notify me", 19);  /*19 <=> image <save>*/

  rec = GUI_Rect(10, 135, 90, 21);
  pDisabledButton = GUI_AddButton(&rec, "disable me", 2);  /*2 <=> image <ESC>*/

  /**
   * add some various checkbox
   */
  rec = GUI_Rect(110, 25, 90, 19);
  GUI_AddCheckBox(&rec, "normal", &check);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_CHECKBOX);

  rec = GUI_Rect(110, 47, 90, 19);
  SetColor(G_COL_TEXT, P2D_Color(0, 140, 0));
  GUI_AddCheckBox(&rec, "color", &check);
  SetColor(G_COL_TEXT, P2D_Color(0, 0, 0));
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_CHECKBOX);

  rec = GUI_Rect(110, 69, 90, 19);
  SetFont(G_FONT_ITALIC);
  GUI_AddCheckBox(&rec, "italic", &check);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_CHECKBOX);
  SetFont(G_FONT_DEFAULT);

  rec = GUI_Rect(110, 91, 90, 19);
  pNotifiedCheck = GUI_AddCheckBox(&rec, "notify me", &check);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_CHECKBOX);

  rec = GUI_Rect(110, 113, 90, 19);
  pDisabledCheck = GUI_AddCheckBox(&rec, "disable me", &check);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_CHECKBOX);


  /**
   * add some various radio
   */
  rec = GUI_Rect(210, 25, 90, 19);
  GUI_AddRadio(&rec, "choice 1.a", &radio1, 1);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_RADIO_1_A);

  rec = GUI_Rect(210, 47, 90, 19);
  SetColor(G_COL_TEXT, P2D_Color(0, 0, 255));
  GUI_AddRadio(&rec, "choice 1.b", &radio1, 2);
  SetColor(G_COL_TEXT, P2D_Color(0, 0, 0));
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_RADIO_1_B);

  rec = GUI_Rect(210, 69, 90, 19);
  SetFont(G_FONT_ITALIC);
  GUI_AddRadio(&rec, "choice 1.c", &radio1, 3);
  SetFont(G_FONT_DEFAULT);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_RADIO_1_C);


  rec = GUI_Rect(210, 113, 90, 19);
  GUI_AddRadio(&rec, "default", &radio2, 1);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_RADIO_2_A);

  rec = GUI_Rect(210, 135, 90, 19);
  pNotifiedRadio = GUI_AddRadio(&rec, "notify me", &radio2, 2);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_RADIO_2_B);

  rec = GUI_Rect(210, 157, 90, 19);
  pDisabledRadio = GUI_AddRadio(&rec, "disable me", &radio2, 3);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_RADIO_2_C);


  /*controls*/
  rec = GUI_Rect(10, 185, 110, 19);
  GUI_AddCheckBox(&rec, "Notify objects", &notifyObj);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_NOTIFY_OBJ);

  rec = GUI_Rect(130, 185, 115, 19);
  GUI_AddCheckBox(&rec, "Disable objects", &disableObj);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_DISABLE_OBJ);

  /*button 'next' */
  rec = GUI_Rect(265, 218, 50, 20);
  GUI_AddButton(&rec, "Next", 5 /*5 <=> image <next>*/);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_BTN_NEXT);

  /*button 'previous' (disabled, no previous page)*/
  rec = GUI_Rect(210, 218, 50, 20);
  GUI_AddButton(&rec, "Prev.", 6 /*6 <=> image <previous>*/);
  GUI_SetSignal(E_PUSHED_TO_RELEASED, SIG_BTN_PREV);

  /*
   * main loop
   */
  while(done == 0) {

    /**
     * user process
     */
     /*none*/


    /**
     * GUI process
     */
    /*execute GUI task*/
    GUI_DrawObjects();

    /*handle user events*/
    switch(GUI_ReadSignal()) {

      case SIG_NOTIFY_OBJ:
        notifyObj = !notifyObj;
        GUI_ObjSetNotified(pNotifiedButton, notifyObj);
        GUI_ObjSetNotified(pNotifiedCheck, notifyObj);
        GUI_ObjSetNotified(pNotifiedRadio, notifyObj);
        break;

      case SIG_DISABLE_OBJ:
        disableObj = !disableObj;
        GUI_ObjSetDisabled(pDisabledButton, disableObj);
        GUI_ObjSetDisabled(pDisabledCheck, disableObj);
        GUI_ObjSetDisabled(pDisabledRadio, disableObj);
        break;

      case SIG_CHECKBOX: check = !check; break;
      case SIG_RADIO_1_A: radio1 = 1; break;
      case SIG_RADIO_1_B: radio1 = 2; break;
      case SIG_RADIO_1_C: radio1 = 3; break;
      case SIG_RADIO_2_A: radio2 = 1; break;
      case SIG_RADIO_2_B: radio2 = 2; break;
      case SIG_RADIO_2_C: radio2 = 3; break;

      case SIG_BTN_NEXT:
        SetPage(DemoPage3);
        done = 1;
        break;

      case SIG_BTN_PREV:
        SetPage(DemoPage1);
        done = 1;
        break;
    }

    /*go to sleep, reducing power consumption*/
    DelayMs(1);
  }
}
