/**
 * @file gui_demo_p5.c
 * @brief quick examples for GUI usage
 * @author Duboisset Philippe
 * @version 0.1b
 * @date (yyyy-mm-dd) 2013-07-13
 *
 * Copyright (C) <2013>  Duboisset Philippe <duboisset.philippe@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "gui_demo.h"

/**
 * The "In/Out" page; arduino I/O control example
 */

#define SIG_CHECKBOX_SET 1
#define SIG_RADIO_IN  2
#define SIG_RADIO_OUT 3
#define SIG_RADIO_PWM 4
#define SIG_TAB_IO    5
#define SIG_TAB_ANA   6
#define SIG_TAB_INFO  7

typedef struct{
  bool bUsable;
  bool bPwm;
} pin_st;

#define NB_PIN 14

const pin_st pins[NB_PIN] = {
  {false, false}, /*pin #0 RX*/
  {false, false}, /*pin #1 TX*/
  {true , false},
  {true , true }, /*pin #3 pwm*/
  {true , false},
  {true , true }, /*pin #5 pwm*/
  {true , true }, /*pin #6 pwm*/
  {true , false},
  {true , false},
  {true , true }, /*pin #9 pwm*/
  {true , true }, /*pin #10 pwm*/
  {true , true }, /*pin #11 pwm*/
  {true , false},
  {true , false}
};




void PageDigitalIO(void) {

  rect_st rec;
  uint16_t cnt;
  char str[10];
  signal_t sig;
  uint8_t done = 0;

  uint8_t states[NB_PIN];
  uint8_t directions[NB_PIN];
  uint8_t sets[NB_PIN];
  uint8_t dutyCycles[NB_PIN];
  g_obj_st *obj;


  /*
   * Page construction
   */

  /*delete all objects & clear the screen*/
  GUI_ClearAll();

  /*tab*/
  rec = GUI_Rect(2, 2, 316, 236);
  obj = GUI_AddParentTab(&rec, 20);
  GUI_AddTabToParent(obj, "In/Out", 42, 1);
  GUI_AddTabToParent(obj, "Analog", 44, 0);
  GUI_SetSignal(E_RELEASED_TO_PUSHED, SIG_TAB_ANA);
  GUI_AddTabToParent(obj, "Info", 30, 0);
  GUI_SetSignal(E_RELEASED_TO_PUSHED, SIG_TAB_INFO);

  rec.h = 17;
  rec.y = 27;
  for(cnt = 0; cnt < NB_PIN; cnt++) {

    states[cnt] = 0;
    directions[cnt] = 0;
    sets[cnt] = 0;
    dutyCycles[cnt] = 127;

    if(pins[cnt].bUsable) {

      rec.x = 8;
      rec.w = 43;
      sprintf(str, "P%02d", cnt);
      GUI_AddLed(&rec, str, &states[cnt]);

      rec.x += rec.w + 1;
      rec.w = 37;
      GUI_AddCheckBox(&rec, "set", &sets[cnt]);
      GUI_SetSignal(E_PUSHED_TO_RELEASED, cnt * 100 + SIG_CHECKBOX_SET);
      rec.x += rec.w + 1;

      rec.w = 33;
      GUI_AddRadio(&rec, "in", &directions[cnt], 0);
      GUI_SetSignal(E_PUSHED_TO_RELEASED, cnt * 100 + SIG_RADIO_IN);

      rec.x += rec.w + 1;
      rec.w = 39;
      GUI_AddRadio(&rec, "out", &directions[cnt], 1);
      GUI_SetSignal(E_PUSHED_TO_RELEASED, cnt * 100 + SIG_RADIO_OUT);

      rec.x += rec.w + 1;
      rec.w = 49;
      GUI_AddRadio(&rec, "pwm", &directions[cnt], 2);
      if(pins[cnt].bPwm) {
        GUI_SetSignal(E_PUSHED_TO_RELEASED, cnt * 100 + SIG_RADIO_PWM);
      }
      else {
        GUI_ObjSetDisabled(NULL, true);
      }

      rec.x += rec.w + 1;
      rec.w = 90;
      rec.y +=3;
      rec.h -=6;
      GUI_AddSlider(&rec, &dutyCycles[cnt]);
      if(pins[cnt].bPwm) {
        //GUI_SetSignal(E_PUSHED_TO_RELEASED, cnt * 100 + SIG_RADIO_PWM);
      }
      else {
        GUI_ObjSetDisabled(NULL, true);
      }
      rec.y -=3;
      rec.h +=6;

      rec.y += rec.h;
    }
  }

  /*main loop*/
  while(done == 0) {

    /**
     * user process
     */
    /*none*/

    /**
     * GUI process
     */
    /*execute GUI task*/
    GUI_DrawObjects();

    /*handle user events*/
    sig = GUI_ReadSignal();
    if(sig) {

      cnt = sig / 100;
      if(cnt < NB_PIN) {

        switch(sig % 100) {

          case SIG_CHECKBOX_SET:
            sets[cnt] = !sets[cnt];
            states[cnt] = sets[cnt];
            break;

          case SIG_RADIO_IN:
            directions[cnt] = 0;
            break;

          case SIG_RADIO_OUT:
            directions[cnt] = 1;
            break;

          case SIG_RADIO_PWM:
            directions[cnt] = 2;
            break;

          case SIG_TAB_ANA:
            done = 1;
            SetPage(PageAna);
            break;

          case SIG_TAB_INFO:
            done = 1;
            SetPage(PageInfo);
            break;

          default:
            break;
        }
      }
    }

    /*release the CPU*/
    DelayMs(1);
  }
}






/**
 * The "Analog" page; arduino ANA input monitoring example
 */
#define NB_ANA        6
#define NB_POINT      140

void PageAna(void) {

  rect_st rec;
  int cnt, tmp, tg;

  uint8_t data[NB_ANA][NB_POINT];
  uint8_t old[NB_ANA];
  float fVal[NB_ANA];
  g_obj_st *obj[NB_ANA], *tab;
  uint8_t done = 0;

  for(tmp = 0; tmp < NB_ANA; tmp++) {
    for(cnt = 0; cnt < NB_POINT; cnt++) {
      data[tmp][cnt] = 127;
    }
    old[tmp] = data[tmp][NB_POINT-1];
    fVal[tmp] = 5.0f * old[tmp] / 255;
  }

  /*
   * Page construction
   */

  /*delete all objects & clear the screen*/
  GUI_ClearAll();

  /*tab*/
  rec = GUI_Rect(2, 2, 316, 236);
  tab = GUI_AddParentTab(&rec, 20);
  GUI_AddTabToParent(tab, "In/Out", 42, 0);
  GUI_SetSignal(E_RELEASED_TO_PUSHED, SIG_TAB_IO);
  GUI_AddTabToParent(tab, "Analog", 44, 1);
  GUI_AddTabToParent(tab, "Info", 30, 0);
  GUI_SetSignal(E_RELEASED_TO_PUSHED, SIG_TAB_INFO);


  /*t3h great copy/paste*/
  rec = GUI_Rect(15, 25, 100, 19);
  GUI_AddText(&rec, "Channel #0:");

  rec = GUI_Rect(115, 25, 40, 19);
  SetColor(G_COL_TEXT, COLOR_RED);
  GUI_AddValueBox(&rec, &fVal[0], BOX_T_FLOAT, "%.2fV");
  SetColor(G_COL_TEXT, COLOR_BLACK);

  rec = GUI_Rect(15, 45, NB_POINT, 48);
  obj[0] = GUI_AddGraph(&rec, 0);
  GUI_AddCurveToGraph(NULL, data[0], COLOR_RED);



  rec = GUI_Rect(165, 25, 100, 19);
  GUI_AddText(&rec, "Channel #1:");

  rec = GUI_Rect(265, 25, 40, 19);
  SetColor(G_COL_TEXT, COLOR_ORANGE);
  GUI_AddValueBox(&rec, &fVal[1], BOX_T_FLOAT, "%.2fV");
  SetColor(G_COL_TEXT, COLOR_BLACK);
  
  rec = GUI_Rect(165, 45, NB_POINT, 48);
  obj[1] = GUI_AddGraph(&rec, 0);
  GUI_AddCurveToGraph(NULL, data[1], COLOR_ORANGE);



  rec = GUI_Rect(15, 95, 100, 19);
  GUI_AddText(&rec, "Channel #2:");

  rec = GUI_Rect(115, 95, 40, 19);
  SetColor(G_COL_TEXT, P2D_Color(180, 180, 0  ));
  GUI_AddValueBox(&rec, &fVal[2], BOX_T_FLOAT, "%.2fV");
  SetColor(G_COL_TEXT, COLOR_BLACK);

  rec = GUI_Rect(15, 115, NB_POINT, 48);
  obj[2] = GUI_AddGraph(&rec, 0);
  GUI_AddCurveToGraph(NULL, data[2], P2D_Color(180, 180, 0  ));



  rec = GUI_Rect(165, 95, 100, 19);
  GUI_AddText(&rec, "Channel #3:");

  rec = GUI_Rect(265, 95, 40, 19);
  SetColor(G_COL_TEXT, P2D_Color(0, 180, 0  ));
  GUI_AddValueBox(&rec, &fVal[3], BOX_T_FLOAT, "%.2fV");
  SetColor(G_COL_TEXT, COLOR_BLACK);

  rec = GUI_Rect(165, 115, NB_POINT, 48);
  obj[3] = GUI_AddGraph(&rec, 0);
  GUI_AddCurveToGraph(NULL, data[3], P2D_Color(0, 180, 0  ));




  rec = GUI_Rect(15, 165, 100, 19);
  GUI_AddText(&rec, "Channel #4:");

  rec = GUI_Rect(115, 165, 40, 19);
  SetColor(G_COL_TEXT, COLOR_BLUE);
  GUI_AddValueBox(&rec, &fVal[4], BOX_T_FLOAT, "%.2fV");
  SetColor(G_COL_TEXT, COLOR_BLACK);

  rec = GUI_Rect(15, 185, NB_POINT, 48);
  obj[4] = GUI_AddGraph(&rec, 0);
  GUI_AddCurveToGraph(NULL, data[4], COLOR_BLUE);



  rec = GUI_Rect(165, 165, 100, 19);
  GUI_AddText(&rec, "Channel #5:");

  rec = GUI_Rect(265, 165, 40, 19);
  SetColor(G_COL_TEXT, COLOR_PURPLE);
  GUI_AddValueBox(&rec, &fVal[5], BOX_T_FLOAT, "%.2fV");
  SetColor(G_COL_TEXT, COLOR_BLACK);

  rec = GUI_Rect(165, 185, NB_POINT, 48);
  obj[5] = GUI_AddGraph(&rec, 0);
  GUI_AddCurveToGraph(NULL, data[5], COLOR_PURPLE);


  /*main loop*/
  while(done == 0) {

    /**
     * user process
     */
    for(tmp = 0; tmp < NB_ANA; tmp++) { //

       tg = (int) old[tmp] + P2D_Rand(10) - 5;

       if(tg < 0) tg = 0;
       else if(tg > 255) tg = 255;
       old[tmp] = tg;
       fVal[tmp] = 5.0f * old[tmp] / 255;


      GUI_AddSampleToCurve(obj[tmp], 0, tg);
    }


    /**
     * GUI process
     */
    /*execute GUI task*/
    GUI_DrawObjects();

    /*handle user events*/
    switch(GUI_ReadSignal()) {

      case SIG_TAB_IO:
        done = 1;
        SetPage(PageDigitalIO);
        break;

      case SIG_TAB_INFO:
        done = 1;
        SetPage(PageInfo);
        break;

      default:
        break;
    }

    /*release CPU*/
    DelayMs(1);
  }
}



/**
 * The "info" page
 */
void PageInfo(void) {

  rect_st rec;

  g_obj_st *obj;
  uint8_t done = 0;

  /*
   * Page construction
   */

  /*delete all objects & clear the screen*/
  GUI_ClearAll();

  /*tab*/
  rec = GUI_Rect(2, 2, 316, 236);
  obj = GUI_AddParentTab(&rec, 20);
  GUI_AddTabToParent(obj, "In/Out", 42, 0);
  GUI_SetSignal(E_RELEASED_TO_PUSHED, SIG_TAB_IO);
  GUI_AddTabToParent(obj, "Analog", 44, 0);
  GUI_SetSignal(E_RELEASED_TO_PUSHED, SIG_TAB_ANA);
  GUI_AddTabToParent(obj, "Info", 30, 1);


  rec = GUI_Rect(35, 50, 316, 25);
  GUI_AddText(&rec, "Schematics, source code & more info at:");

  rec = GUI_Rect(45, 70, 316, 35);
  SetColor(G_COL_TEXT, COLOR_BLUE);
  SetFont(G_FONT_BIG);
  GUI_AddText(&rec, "www.herptronix.blogspot.com");
  SetColor(G_COL_TEXT, COLOR_BLACK);
  SetFont(G_FONT_DEFAULT);

  rec = GUI_Rect(80, 110, 316, 25);
  GUI_AddText(&rec, "Thank you for watching");


  /*main loop*/
  while(done == 0) {

    /**
     * GUI process
     */
    /*execute GUI task*/
    GUI_DrawObjects();

    /*handle user events*/
    switch(GUI_ReadSignal()) {

      case SIG_TAB_IO:
        done = 1;
        SetPage(PageDigitalIO);
        break;

      case SIG_TAB_ANA:
        done = 1;
        SetPage(PageAna);
        break;

      default:
        break;
    }

    /*release CPU*/
    DelayMs(1);
  }
}
