/**
 * @file main.c
 * @brief entry point
 * @author Duboisset Philippe
 * @version 0.1b
 * @date (yyyy-mm-dd) 2013-07-13
 *
 * Copyright (C) <2013>  Duboisset Philippe <duboisset.philippe@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <plib.h>           /* Include to use PIC32 peripheral libraries      */
#include <stdint.h>         /* For uint32_t definition                        */
#include <stdbool.h>        /* For true/false definition                      */

#include "main.h"
#include "ILI9320.h"
#include "backlight.h"
#include "touchscreen.h"

#include "ticks.h"
#include "delay.h"
#include "uc.h"
#include "resources.h"
#include "p2d.h"
#include "gui.h"

#include "gui_demo.h"




int32_t main(void) {

  touch_calib_st cal;

  UcInit();
  TicksInit();
  LCD_Init();
  P2D_Init();
  DelayMs(120);                 /*wait a bit before turning on the backlight (avoids a flash)*/
  BacklightInit();

  /*calibration point #1*/
  cal.xd1 = 32;
  cal.yd1 = 24;
  cal.xt1 = 160;
  cal.yt1 = 805;

  /*calibration point #2*/
  cal.xd2 = 288;
  cal.yd2 = 216;
  cal.xt2 = 825;
  cal.yt2 = 170;

  /*enable & calibrate the touchscreen*/
  TouchScreenEnable();
  TouchScreenCalib(&cal);

  /*init the GUI*/
  GUI_Init();
  
  /*main task*/
  GUI_Demo();


  /*never arrive here*/
  while(1) {
    DelayMs(1000);
  }
  return -1;
}






#if 0
static void TestTouchscreen(void) {

  uint16_t x0, y0;
  touch_calib_st cal;
  char str[50];

  /*calibration point #1*/
  cal.xd1 = 32;
  cal.yd1 = 24;
  cal.xt1 = 163;
  cal.yt1 = 800;

  /*calibration point #2*/
  cal.xd2 = 288;
  cal.yd2 = 216;
  cal.xt2 = 820;
  cal.yt2 = 185;

  /*enable & calibrate the touchscreen*/
  TouchScreenEnable();
  TouchScreenCalib(&cal);

  P2D_SetColors(0x0000, 0x0000);
  P2D_SetClip(NULL);
  P2D_Clear();

  P2D_SetFont(FontFreeSerif_4bpp_n_16);
  P2D_SetPixel(32,24,COLOR_GREEN);
  P2D_SetPixel(288,216,COLOR_GREEN);

  while(1) {
    TouchScreenReadRaw(&x0, &y0);

    sprintf(str, "x:%04d, y:%04d     ", x0, y0);
    P2D_SetColors(0xFFFF, 0x0000);
    P2D_PutText(20,100,str);
    DelayMs(1);
  }
}
#endif

#if 0
  //first proto
  /*calibration point #1*/
  cal.xd1 = 32;
  cal.yd1 = 24;
  cal.xt1 = 163;
  cal.yt1 = 800;

  /*calibration point #2*/
  cal.xd2 = 288;
  cal.yd2 = 216;
  cal.xt2 = 820;
  cal.yt2 = 185;
#endif
